粵語編程語言鼓勵來自各路程序員嘅貢獻！
# 代碼貢獻指示與準則
1. Fork該項目 並克隆
```sh
git clone https://github.com/StepfenShawn/Cantonese
```
2. 創建 Feature 分支
```sh
$ git checkout -b AmazingFeature
```
3. 提交改動
```sh
$ git commit -m "Add some Amazing Features"
```
4. Push 分支
```sh
$ git push origin AmazingFeature
```
5. Pull Request
6. 請簡單說明該 PR 在哪方面進行了改進，最好解釋點解寫這個 PR

We really encourage you to contribute to the Cantonese programming language!
# Instructions to Contribute to **Cantonese** Project
1. Fork the repo:
```sh
git clone https://github.com/StepfenShawn/Cantonese
```
2. Create your Feature Branch
```sh
$ git checkout -b AmazingFeature
```
3. Commit your Changes 
```sh
$ git commit -m "Add some Amazing Features"
```
4. Push to the Branch 
```sh
$ git push origin AmazingFeature
```
5. Open a Pull Request
6. Please briefly demonstrate what changes this PR made, and better explain why you made this PR
